/*
 *  Copyright 2011 Ruediger Gad
 *
 *  This file is part of Q To-Do.
 *
 *  Q To-Do is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Q To-Do is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Q To-Do.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1
import com.meego 1.0
import qtodo 1.0

PageStackWindow {
    id: appWindow

    initialPage: mainPage

    Page {
        id: mainPage
        tools: commonTools

        Rectangle{
            anchors.fill: parent
            color: "white"

            TreeView {
                id: treeView
                anchors.fill: parent
                model: rootElementModel

                onCurrentItemChanged: {
                    if(currentItem === null) {
                        iconDelete.enabled = false
                        iconEdit.enabled = false
                        iconMarkDone.enabled = false
                    }else{
                        iconDelete.enabled = true
                        iconEdit.enabled = true
                        iconMarkDone.enabled = true

                        if(currentItem.type === "note"){
                            iconMarkDone.enabled = false
                        }else{
                            iconMarkDone.enabled = true
                        }

                    }
                }
            }
        }
    }

    QueryDialog {
        id: confirmDeleteDialog

        titleText: "Delete?"

        acceptButtonText: "OK"
        rejectButtonText: "Cancel"

        onAccepted: treeView.currentModel.deleteElement(treeView.currentIndex)
    }

    EditToDoSheet{ id: editToDoSheet }

    ToolBarLayout {
        id: commonTools
        visible: true

        ToolIcon { id: iconDelete; platformIconId: "toolbar-delete"
            onEnabledChanged: platformIconId = "toolbar-delete" + ((enabled) ? "" : "-dimmed")
            onClicked: {
                confirmDeleteDialog.message = "Delete \"" + treeView.currentItem.text + "\"?"
                confirmDeleteDialog.open()
            }
        }
        ToolIcon { id: iconEdit; platformIconId: "toolbar-edit"
            onEnabledChanged: platformIconId = "toolbar-edit" + ((enabled) ? "" : "-dimmed")
            onClicked: {
                editToDoSheet.color = treeView.currentItem.color
                editToDoSheet.type = treeView.currentItem.type
                editToDoSheet.text = treeView.currentItem.text
                editToDoSheet.edit = true
                editToDoSheet.open()
            }
        }
        ToolIcon { id: iconAdd; platformIconId: "toolbar-add"
            onEnabledChanged: platformIconId = "toolbar-add" + ((enabled) ? "" : "-dimmed")
            onClicked: {
                editToDoSheet.color = "blue"
                editToDoSheet.type = "to-do"
                editToDoSheet.text = ""
                editToDoSheet.edit = false
                editToDoSheet.open()
            }
        }
        ToolIcon { id: iconMarkDone; platformIconId: "toolbar-done"
            onEnabledChanged: platformIconId = "toolbar-done" + ((enabled) ? "" : "-dimmed")
            onClicked: {
                if(treeView.currentItem.done){
                    treeView.currentModel.setAttribute(treeView.currentIndex, "done", "false")
                }else{
                    treeView.currentModel.setAttribute(treeView.currentIndex, "done", "true")
                }
            }
        }
        ToolIcon { id: iconBack; platformIconId: "toolbar-previous"
            enabled: treeView.currentLevel > 0
            onEnabledChanged: platformIconId = "toolbar-previous" + ((enabled) ? "" : "-dimmed")
            onClicked: treeView.currentLevel--
        }
        /*
        ToolIcon { id: iconMenu; platformIconId: "toolbar-view-menu"
             anchors.right: parent===undefined ? undefined : parent.right
             onClicked: (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
             onEnabledChanged: platformIconId = "toolbar-view-menu" + ((enabled) ? "" : "-dimmed")
        }
        */
    }

    /*
    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem { text: "Sample menu item" }
        }
    }
    */

    NodeListModel{
        id: rootElementModel

        onChanged: storage.save()
    }

    ToDoStorage{
        id: storage

        onDocumentOpened: {
            console.log("Document opened.")
            rootElementModel.setRoot(storage);
        }
    }

    Component.onCompleted: {
        storage.open()
//        storage.open("/opt/qtodo/sample.xml")

        iconDelete.enabled = false
        iconEdit.enabled = false
        iconMarkDone.enabled = false
    }
}
